@@ -1,15 +1,23 @@
+/*
+ * Summary: Windows configuration header
+ * Description: Windows configuration header
+ *
+ * Copy: See Copyright for the status of this software.
+ *
+ * Author: Igor Zlatkovic
+ */
 #ifndef __LIBXSLT_WIN32_CONFIG__
 #define __LIBXSLT_WIN32_CONFIG__
 
-#define HAVE_CTYPE_H
-#define HAVE_STDLIB_H
-#define HAVE_MALLOC_H
-#define HAVE_TIME_H
-#define HAVE_LOCALTIME
-#define HAVE_GMTIME
-#define HAVE_TIME
-
-#define HAVE_FCNTL_H
+#define HAVE_CTYPE_H 1
+#define HAVE_STDLIB_H 1
+#define HAVE_MALLOC_H 1
+#define HAVE_TIME_H 1
+#define HAVE_LOCALTIME 1
+#define HAVE_GMTIME 1
+#define HAVE_TIME 1
+#define HAVE_MATH_H 1
+#define HAVE_FCNTL_H 1
 
 #include <io.h>
 
