@@ -26,12 +26,15 @@ libxslt_xsltParseStylesheetImportedDoc(PyObject *self ATTRIBUTE_UNUSED, PyObject
     xsltStylesheetPtr c_retval;
     xmlDocPtr doc;
     PyObject *pyobj_doc;
+    xsltStylesheetPtr style;
+    PyObject *pyobj_style;
 
-    if (!PyArg_ParseTuple(args, (char *)"O:xsltParseStylesheetImportedDoc", &pyobj_doc))
+    if (!PyArg_ParseTuple(args, (char *)"OO:xsltParseStylesheetImportedDoc", &pyobj_doc, &pyobj_style))
         return(NULL);
     doc = (xmlDocPtr) PyxmlNode_Get(pyobj_doc);
+    style = (xsltStylesheetPtr) Pystylesheet_Get(pyobj_style);
 
-    c_retval = xsltParseStylesheetImportedDoc(doc);
+    c_retval = xsltParseStylesheetImportedDoc(doc, style);
     py_retval = libxslt_xsltStylesheetPtrWrap((xsltStylesheetPtr) c_retval);
     return(py_retval);
 }
@@ -52,20 +55,25 @@ libxslt_xsltGenerateIdFunction(PyObject *self ATTRIBUTE_UNUSED, PyObject *args)
 }
 
 PyObject *
-libxslt_xsltParseGlobalParam(PyObject *self ATTRIBUTE_UNUSED, PyObject *args) {
-    xsltStylesheetPtr style;
-    PyObject *pyobj_style;
-    xmlNodePtr cur;
+libxslt_xsltAttrListTemplateProcess(PyObject *self ATTRIBUTE_UNUSED, PyObject *args) {
+    PyObject *py_retval;
+    xmlAttrPtr c_retval;
+    xsltTransformContextPtr ctxt;
+    PyObject *pyobj_ctxt;
+    xmlNodePtr target;
+    PyObject *pyobj_target;
+    xmlAttrPtr cur;
     PyObject *pyobj_cur;
 
-    if (!PyArg_ParseTuple(args, (char *)"OO:xsltParseGlobalParam", &pyobj_style, &pyobj_cur))
+    if (!PyArg_ParseTuple(args, (char *)"OOO:xsltAttrListTemplateProcess", &pyobj_ctxt, &pyobj_target, &pyobj_cur))
         return(NULL);
-    style = (xsltStylesheetPtr) Pystylesheet_Get(pyobj_style);
-    cur = (xmlNodePtr) PyxmlNode_Get(pyobj_cur);
+    ctxt = (xsltTransformContextPtr) PytransformCtxt_Get(pyobj_ctxt);
+    target = (xmlNodePtr) PyxmlNode_Get(pyobj_target);
+    cur = (xmlAttrPtr) PyxmlNode_Get(pyobj_cur);
 
-    xsltParseGlobalParam(style, cur);
-    Py_INCREF(Py_None);
-    return(Py_None);
+    c_retval = xsltAttrListTemplateProcess(ctxt, target, cur);
+    py_retval = libxml_xmlNodePtrWrap((xmlNodePtr) c_retval);
+    return(py_retval);
 }
 
 PyObject *
@@ -318,22 +326,6 @@ libxslt_xsltGetNamespace(PyObject *self ATTRIBUTE_UNUSED, PyObject *args) {
     return(py_retval);
 }
 
-PyObject *
-libxslt_xsltTransformGetInsertNode(PyObject *self ATTRIBUTE_UNUSED, PyObject *args) {
-    PyObject *py_retval;
-    xmlNodePtr c_retval;
-    xsltTransformContextPtr ctxt;
-    PyObject *pyobj_ctxt;
-
-    if (!PyArg_ParseTuple(args, (char *)"O:xsltTransformGetInsertNode", &pyobj_ctxt))
-        return(NULL);
-    ctxt = (xsltTransformContextPtr) PytransformCtxt_Get(pyobj_ctxt);
-
-    c_retval = ctxt->insert;
-    py_retval = libxml_xmlNodePtrWrap((xmlNodePtr) c_retval);
-    return(py_retval);
-}
-
 PyObject *
 libxslt_xsltFreeDocuments(PyObject *self ATTRIBUTE_UNUSED, PyObject *args) {
     xsltTransformContextPtr ctxt;
@@ -656,28 +648,6 @@ libxslt_xsltFunctionNodeSet(PyObject *self ATTRIBUTE_UNUSED, PyObject *args) {
     return(Py_None);
 }
 
-PyObject *
-libxslt_xsltAttrListTemplateProcess(PyObject *self ATTRIBUTE_UNUSED, PyObject *args) {
-    PyObject *py_retval;
-    xmlAttrPtr c_retval;
-    xsltTransformContextPtr ctxt;
-    PyObject *pyobj_ctxt;
-    xmlNodePtr target;
-    PyObject *pyobj_target;
-    xmlAttrPtr cur;
-    PyObject *pyobj_cur;
-
-    if (!PyArg_ParseTuple(args, (char *)"OOO:xsltAttrListTemplateProcess", &pyobj_ctxt, &pyobj_target, &pyobj_cur))
-        return(NULL);
-    ctxt = (xsltTransformContextPtr) PytransformCtxt_Get(pyobj_ctxt);
-    target = (xmlNodePtr) PyxmlNode_Get(pyobj_target);
-    cur = (xmlAttrPtr) PyxmlNode_Get(pyobj_cur);
-
-    c_retval = xsltAttrListTemplateProcess(ctxt, target, cur);
-    py_retval = libxml_xmlNodePtrWrap((xmlNodePtr) c_retval);
-    return(py_retval);
-}
-
 PyObject *
 libxslt_xsltCleanupTemplates(PyObject *self ATTRIBUTE_UNUSED, PyObject *args) {
     xsltStylesheetPtr style;
@@ -1038,6 +1008,23 @@ libxslt_xsltRegisterTestModule(PyObject *self ATTRIBUTE_UNUSED, PyObject *args A
     return(Py_None);
 }
 
+PyObject *
+libxslt_xsltParseGlobalParam(PyObject *self ATTRIBUTE_UNUSED, PyObject *args) {
+    xsltStylesheetPtr style;
+    PyObject *pyobj_style;
+    xmlNodePtr cur;
+    PyObject *pyobj_cur;
+
+    if (!PyArg_ParseTuple(args, (char *)"OO:xsltParseGlobalParam", &pyobj_style, &pyobj_cur))
+        return(NULL);
+    style = (xsltStylesheetPtr) Pystylesheet_Get(pyobj_style);
+    cur = (xmlNodePtr) PyxmlNode_Get(pyobj_cur);
+
+    xsltParseGlobalParam(style, cur);
+    Py_INCREF(Py_None);
+    return(Py_None);
+}
+
 PyObject *
 libxslt_xsltLoadStylesheetPI(PyObject *self ATTRIBUTE_UNUSED, PyObject *args) {
     PyObject *py_retval;
@@ -1322,6 +1309,22 @@ libxslt_xsltUnregisterExtModule(PyObject *self ATTRIBUTE_UNUSED, PyObject *args)
     return(py_retval);
 }
 
+PyObject *
+libxslt_xsltTransformGetInsertNode(PyObject *self ATTRIBUTE_UNUSED, PyObject *args) {
+    PyObject *py_retval;
+    xmlNodePtr c_retval;
+    xsltTransformContextPtr ctxt;
+    PyObject *pyobj_ctxt;
+
+    if (!PyArg_ParseTuple(args, (char *)"O:xsltTransformGetInsertNode", &pyobj_ctxt))
+        return(NULL);
+    ctxt = (xsltTransformContextPtr) PytransformCtxt_Get(pyobj_ctxt);
+
+    c_retval = ctxt->insert;
+    py_retval = libxml_xmlNodePtrWrap((xmlNodePtr) c_retval);
+    return(py_retval);
+}
+
 PyObject *
 libxslt_xsltStylesheetGetNext(PyObject *self ATTRIBUTE_UNUSED, PyObject *args) {
     PyObject *py_retval;
